@@ -1,15 +1,15 @@
 package XML::Grammar::Fortune::ToText;
-$XML::Grammar::Fortune::ToText::VERSION = '0.0801';
+$XML::Grammar::Fortune::ToText::VERSION = '0.0802';
 use warnings;
 use strict;
 
-use XML::LibXML;
-use Text::Format;
-use List::Util (qw(max));
+use XML::LibXML qw/ XML_CDATA_SECTION_NODE XML_ELEMENT_NODE XML_TEXT_NODE /;
+use Text::Format ();
+use List::Util   (qw(max));
 
 use Carp ();
 
-use MooX qw/late/;
+use MooX qw/ late /;
 
 has '_formatter' => (
     is      => 'rw',
@@ -23,11 +23,11 @@ has '_formatter' => (
         );
     },
 );
-has '_is_first_line' => ( isa => "Bool", is       => 'rw' );
-has '_input'         => ( is  => 'rw',   init_arg => 'input', required => 1, );
-has '_output'        => ( is  => 'rw',   init_arg => 'output', required => 1, );
-has '_this_line'     => ( isa => 'Str',  is       => 'rw', default => '', );
-has '_buf' => (
+has '_is_first_line' => ( isa => "Bool", is      => 'rw' );
+has '_input'         => ( is  => 'rw',  init_arg => 'input',  required => 1, );
+has '_output'        => ( is  => 'rw',  init_arg => 'output', required => 1, );
+has '_this_line'     => ( isa => 'Str', is       => 'rw',     default  => '', );
+has '_buf'           => (
     isa     => 'ScalarRef[Str]',
     is      => 'rw',
     default => sub { my $s = ''; return \$s; }
@@ -762,7 +762,7 @@ XML::Grammar::Fortune::ToText - convert the FortunesXML grammar to plaintext.
 
 =head1 VERSION
 
-version 0.0801
+version 0.0802
 
 =head1 SYNOPSIS
 
@@ -810,47 +810,13 @@ Runs the processor.
 
 Shlomi Fish, L<http://www.shlomifish.org/> .
 
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-xml-grammar-fortune at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fortune>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc XML::Grammar::Fortune
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fortune>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/XML-Grammar-Fortune>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/XML-Grammar-Fortune>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/XML-Grammar-Fortune>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008 by Shlomi Fish
 
-This program is distributed under the MIT (X11) License:
+This program is distributed under the MIT (Expat) License:
 L<http://www.opensource.org/licenses/mit-license.php>
 
 Permission is hereby granted, free of charge, to any person
